<?php
session_start();
require_once('config.php');
require_once('dbutils.php');
require_once('locationfuncs.php');
require_once('externaldbfuncs.php');

$masterdb = new GenericSqliteTable("var/master.db","master");
$areadb = new GenericSqliteTable("var/area.db","area");

$listAreas = $areadb->GetKeys();
$nameCol = GetConfigOption('nameCol');

if(GetConfigOption('enableArea'))
{
	if(isset($_GET['area'])) $_SESSION['area'] = $_GET['area'];
	if(!isset($_GET['area']) and isset($_SESSION['area'])) $_GET['area'] = $_SESSION['area'];
	if(!isset($_GET['area'])) $_GET['area'] = $listAreas[0];
	$ids = $areadb[$_GET['area']];
}
else
{
	$ids = $masterdb->GetKeys();
}


//Find marker locations and external links
$bestlocs = array();
$bestosm = array();
$markercol = array();
$minlat = Null; $maxlat = Null; $minlon = Null; $maxlon = Null;
foreach($ids as $id)
{
	$ret = GetBestLocation($id);
	$bestlocs[$id] = $ret;
	$ret = GetBestOsmLink($id);
	$bestosm[$id] = $ret;
	//print_r($bestlocs[$id]);

	//Determine marker status
	$located = 0;
	$presentOsm = 0;
	if($bestlocs[$id][0] != Null and !$bestlocs[$id][1])
		$located = 1;
	if(!$located and $bestosm[$id][0] != Null)
		$presentOsm = 1;

	//Assign colour
	$markercol[$id] = "red";
	if($presentOsm) $markercol[$id] = "yellow";
	if($located) $markercol[$id] = "green";

	//Update bounding box
	if($bestlocs[$id][0]!==null)
	{
		$lat = $bestlocs[$id][0][0]; $lon = $bestlocs[$id][0][1];
		if(is_null($minlat) or $minlat > $lat) $minlat = $lat;
		if(is_null($maxlat) or $maxlat < $lat) $maxlat = $lat;
		if(is_null($minlon) or $minlon > $lon) $minlon = $lon;
		if(is_null($maxlon) or $maxlon < $lon) $maxlon = $lon;
	}
}
$midlat = 0.5 * ($minlat + $maxlat);
$midlon = 0.5 * ($minlon + $maxlon);

//If bounds not set, zoom out to entire world
$initialZoom = GetConfigOption('initialZoomOverview');;
if($minlat === Null or $minlon === Null)
{
	$midlat = 0.;
	$midlon = 0.;
	$initialZoom = 2;
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<!-- 

First, we have the code for the HTML header. The important part is where the 
javascript is included to enable google maps.

-->

<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
	<title><?php echo GetConfigOption('overallTitle').", ".GetConfigOption('subTitle');?></title>
	<script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=false"></script>
	<script type="text/javascript" src="googlemap.js"></script>

</head>

<!--

Now comes the body of the HTML page. Notice the onload function on the first line.
That goes the map code started and makes the map work properly.

-->

<body onload="initializeMap(<?php echo $midlat.",".$midlon.",".$initialZoom; ?>,'osm'); Test();">

<div id="map_canvas" style="width: 100%; height: 400px;"></div>

<!-- 

The next section creates the text that appears under the map. It should be reworded as necessary. 
Please respect the licenses but you can include your own text and formatting as needed 

-->

<p>Green: position accurately known, Yellow: present in OSM, Red: Missing/inaccurate POI.</p>

<h3>Marker Copyright Information</h3>
<?php 

$listLicenses = array();
foreach($bestlocs as $k => $posdata)
{
	//echo $k." ";
	//print_r($posdata);
	//echo "<br/>\n";
	$lic = $posdata['license'];
	if(!in_array($lic, $listLicenses))
		$listLicenses[$lic] = array();
	$source = $posdata['source'];
	if(!in_array($source, $listLicenses[$lic]))
		array_push($listLicenses[$lic],$source);
}
if(count($listLicenses)>0) 
{
echo "<p>The markers positions and data are licensed under the following terms:</p><ul>\n";
foreach($listLicenses as $lic => $sources)
	foreach($sources as $source)
	{
		echo "<li>".$source. " data under the terms of ".$lic.".</li>\n";
	}
echo "</ul>\n";
}

?>
<p>Generally, these copyright notices should be retained, unless you know what you are legally doing.</p>

<h3>Instructions for Embedding</h3>

<p>Download this page as HTML only in your browser.</p>

<p>Copy a few image files used for the markers and one javascript file. The default locations are that google.js goes in the same folder as this HTML. The image files should go in a folder named "img".</p>

<p><a href="img/map_marker_green.png"><img src="img/map_marker_green.png" alt="Marker graphic"/></a>
<a href="img/map_marker_yellow.png"><img src="img/map_marker_yellow.png" alt="Marker graphic"/></a>
<a href="img/map_marker_red.png"><img src="img/map_marker_red.png" alt="Marker graphic"/></a> 
<a href="googlemap.js">googlemap.js</a>
</p>
<p>Test the page on your server (or hard drive). If no map appears, googlemap.js is probably missing. If the map but no markers appear, your marker images are probably missing or in the wrong place.</p>
<p>Look at the code for the HTML and adjust to make it fit with the rest of your web page. There are comments to assist you.</p>


<!-- 

This section specifies where the markers should appear on the map and
the text that appears in the information bubble, when a marker is clicked.

-->

<script type="text/javascript">
// <![CDATA[
function Test()
{
	$windows = [];
	var infowindow = new google.maps.InfoWindow({});
<?php

foreach($ids as $id)
{
	$record = $masterdb[$id];
	list($osmtype,$osmid) = $bestosm[$id];
	$loc = $bestlocs[$id];
	list($pos,$rough) = $loc;
	if($pos == Null) continue;
?>
	var latLng = new google.maps.LatLng(<?php echo $pos['0']; ?>, <?php echo $pos['1']; ?>);
	var markerImage = new google.maps.MarkerImage('img/map_marker_<?php echo $markercol[$id];?>.png',null,null,new google.maps.Point(10, 34));

	var marker = new google.maps.Marker({
	  position: latLng,
	  title: "<?php echo htmlspecialchars($record[$nameCol]); ?>",
	  map: map,
	  draggable: false,
	  icon: markerImage
	});
	//marker.setIcon('map_marker_<?php echo $markercol[$id];?>.png')

	window["marker<?php echo $id;?>"] = marker;

	google.maps.event.addListener(marker, 'click', function() {
		infowindow.setContent("<h3><?php echo htmlspecialchars($record[$nameCol]); ?></h3><ul><?php
		foreach($record as $k => $v)
		{
			if($k == "key") continue; //Generic Sqlite table quirk
			echo "<li>".htmlspecialchars($k).":".addslashes($v)."</li>";
		}

		?><p>Position from <?php echo $loc['source']." (".$loc['nickname']."), license under ".$loc['license'].".";?></p></ul>"); 
		infowindow.open(map,marker<?php echo $id;?>);
	});
<?php
}
?>
}
// ]]>
</script>
</body>
</html>

<!--

That's it!

-->
<?php $footerDone = 1; ?>
