<?php
session_start();
require_once('config.php');
require_once('dbutils.php');
require_once('locationfuncs.php');

require_once('codepoint/codepointconfig.php');
$configCodePointFile = GetConfigOption('codepointFile');
require_once('codepoint/codepoint.php');

require_once('ostn02php/ostn02config.php');
$config_OSTN02_bz2_file = GetConfigOption('ostn02bzFile');
$config_OSTN02_sqlite_file = GetConfigOption('ostn02sqliteFile');
require_once('ostn02php/OSTN02.php');
require_once('ostn02php/OSGB.php');

$masterdb = new GenericSqliteTable("var/master.db","master");
$nameCol = GetConfigOption('nameCol');

$isPostcode = (!strpos($_GET['loc'],","));

if($isPostcode and !CodepointReady()) die("Codepoint database not ready.");
if($isPostcode)
{
	$pos = GetCodepointPos($_GET['loc']);
	
	try
	{
		list($x,$y,$h) = OSGB36_to_ETRS89 ($pos[0],$pos[1]);
	}
	catch (Exception $e) {
		echo 'Caught exception: ',  $e->getMessage(), "\n";
		continue;
	}
	
	list($lat, $lon) = grid_to_ll($x, $y);
}

if(!$isPostcode)
{
	list($lat,$lon) = explode(",",$_GET['loc']);
}

//Validate
$lat = (float)$lat;
$lon = (float)$lon;

//Get feature IDs
if(GetConfigOption('enableArea'))
{
	if(isset($_GET['area'])) $_SESSION['area'] = $_GET['area'];
	if(!isset($_GET['area']) and isset($_SESSION['area'])) $_GET['area'] = $_SESSION['area'];
	if(!isset($_GET['area'])) $_GET['area'] = $listAreas[0];
	$ids = $areadb[$_GET['area']];
}
else
{
	$ids = $masterdb->GetKeys();
}

//Get positions of features
foreach($ids as $id)
{
	$ret = GetBestLocation($id);
	$bestlocs[$id] = $ret;
}

$inputPos = LatLonToCartesian($lat,$lon);
$dists = array();
$indexedDists = array();
//Calculate Distance
foreach($ids as $id)
{
	if($bestlocs[$id][0]===null) continue;
	$fLatLon = $bestlocs[$id][0];
	$fPos = LatLonToCartesian($fLatLon[0],$fLatLon[1]);
	$dist = PythagDist($fPos,$inputPos);
	//echo $id.",".$dist."</br>\n";
	array_push($dists, $dist);
	$indexedDists[$id] = $dist;
}

array_multisort($dists,$ids);

//print_r($dists);

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<!--
Design by Free CSS Templates
http://www.freecsstemplates.org
Released for free under a Creative Commons Attribution 2.5 License

Name       : Tomatoes
Description: A two-column, fixed-width design for 1024x768 screen resolutions.
Version    : 1.0
Released   : 20110301

-->
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<title><?php echo GetConfigOption('overallTitle').", ".GetConfigOption('subTitle');?></title>
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="style.css" rel="stylesheet" type="text/css" media="screen" />
</head>
<body>
<div id="wrapper">
	<div id="header">
		<div id="menu">
			<ul>
				<?php $pageCatExplore = 1;
				require('topbar.php'); ?>
			</ul>
		</div>
		<!-- end #menu -->
	</div>
	<div id="logo">
		<h1><a href="#"><?php echo GetConfigOption('overallTitle');?></a></h1>
		<p><em><?php echo GetConfigOption('subTitle');?></em></p>
	</div>
	<hr />
	<!-- end #logo -->
	<div id="page">
		<div id="page-bgtop">
			<div id="content">
				<div class="post">
					<h2 class="title"><a href="#">Results Near to <?php echo $_GET['loc'];?></a></h2>
					<?php foreach(array_slice($ids,0,20) as $id) { ?>
					<div class="entry">
						<p><?php 
						$rec = $masterdb[$id];
						echo "<a href=\"details?id=".$id."\">".$rec[$nameCol]."</a>, ";

						printf("%.2f km. ",$indexedDists[$id]);
						?>

						<?php $loc = $bestlocs[$id][0];
						echo GenerateViewHtml($loc[0],$loc[1]);
						
						?>
						</p>
					</div>
					<?php } ?>
				</div>
			</div>
			<!-- end #content -->
			<div id="sidebar">
				<ul>
					<?php require('sidebar.php'); ?>

				</ul>
			</div>
			<!-- end #sidebar -->
			<div style="clear: both;">&nbsp;</div>
		</div>
	</div>
	<!-- end #page -->
	<div id="footer">

<?php
	require_once('footer.php');
?>
	</div>
	<!-- end #footer -->
</div>
</body>
</html>
